#include "testApp.h"


//--------------------------------------------------------------
void testApp::setup(){	
	
	ofSetVerticalSync(true);
	ofSetFrameRate(60);
	ofBackground(0, 0, 0);
	
	for (int i = 0; i < ;500 i++){
		particle myParticle;
		myParticle.setInitialCondition(ofRandom(0,ofGetWidth()),ofRandom(0,ofGetHeight()),0,0);
		particles.push_back(myParticle);
	}
	bFill = false;
	bLines = false;
	bShowField = false;   
	VF.setupField(60,40,ofGetWidth(), ofGetHeight());
	
}

//--------------------------------------------------------------
void testApp::update(){
	for (int i = 0; i < particles.size(); i++)
	{
		particles[i].resetForce();
		ofxVec2f frc;
		frc = VF.getForceFromPos(particles[i].pos.x, particles[i].pos.y);
		VF.addInwardCircle(ofGetWidth()/2, ofGetHeight()/2, ofGetWidth(), .0005);
		particles[i].addForce(frc.x, frc.y);
		particles[i].addDampingForce();
		particles[i].bounceOffWalls();
		particles[i].update();	
	}
	
	
	VF.fadeField(0.99f);

}

//--------------------------------------------------------------
void testApp::draw(){
	ofSetColor(0,130,130, 200);
	ofSetColor(0x000000);
	float dist,pcount = 0;
	ofEnableAlphaBlending();
	for (int i = 0; i < particles.size(); i++)
	{
		particles[i].draw();
		for (int j = 0; j < particles.size(); j++)
		{
			dist = ofDist(particles[i].pos.x, particles[i].pos.y, particles[j].pos.x, particles[j].pos.y);
			if(dist <=150 && i != j)
			{	
				float alpha = ofMap(dist,0, 150, 0, 20);
				ofSetColor(255,255,255,20-alpha);
				ofBeginShape();
					ofFill();
					ofVertex(particles[i].pos.x, particles[i].pos.y);
					ofVertex(particles[j].pos.x, particles[j].pos.y);
					ofVertex(particles[j].pos.x + dist/4 , particles[j].pos.y + dist/4);
	
				ofEndShape(false);
				pcount++;
			}
			if(bFill)
			{
				if(pcount > 150)
				{
					VF.addOutwardCircle(particles[i].pos.x, particles[i].pos.y, 150,ofRandom(0.4f,0.6f));
					pcount = 0;
				}
			}
		}		
	}
	ofDisableAlphaBlending();
	
}

//--------------------------------------------------------------
void testApp::keyPressed  (int key){ 
	
	if (key == ' ')VF.clear();
	if (key == 'f') (bFill) ? bFill = false : bFill = true;

}

//--------------------------------------------------------------
void testApp::keyReleased  (int key){ 
}

//--------------------------------------------------------------
void testApp::mouseMoved(int x, int y ){
}

//--------------------------------------------------------------
void testApp::mouseDragged(int x, int y, int button){
	
	float diffx = x - prevMouseX;
	float diffy = y - prevMouseY;
	
	if(button == 0)
	{
		VF.addVectorCircle((float)x, (float)y, diffx*0.3, diffy*0.3, ofRandom(60,150), 0.5f);
		VF.addInwardCircle((float)x, (float)y, ofRandom(150,300),ofRandom(0.1f,0.3f));
		VF.addClockwiseCircle((float)x, (float)y, ofRandom(40,200),ofRandom(0.1f,0.3f));

	}
	else
	{
		VF.addOutwardCircle((float)x, (float)y, ofRandom(150,300),ofRandom(0.7f,0.8f));
		VF.addClockwiseCircle((float)x, (float)y, ofRandom(40,200),ofRandom(0.1f,0.3f));
	}
	prevMouseX = x;
	prevMouseY = y;
}

//--------------------------------------------------------------
void testApp::mousePressed(int x, int y, int button){
	prevMouseX = x; 
	prevMouseY = y;
}

//--------------------------------------------------------------
void testApp::mouseReleased(){
}
